( cd usr/bin ; rm -rf mailq )
( cd usr/bin ; ln -sf smail mailq )
( cd usr/bin ; rm -rf mkaliases )
( cd usr/bin ; ln -sf ../lib/smail/mkaliases mkaliases )
( cd usr/bin ; rm -rf newaliases )
( cd usr/bin ; ln -sf smail newaliases )
( cd usr/bin ; rm -rf pathto )
( cd usr/bin ; ln -sf smail pathto )
( cd usr/bin ; rm -rf rsmtp )
( cd usr/bin ; ln -sf smail rsmtp )
( cd usr/bin ; rm -rf runq )
( cd usr/bin ; ln -sf smail runq )
( cd usr/bin ; rm -rf smtpd )
( cd usr/bin ; ln -sf smail smtpd )
( cd usr/bin ; rm -rf uupath )
( cd usr/bin ; ln -sf smail uupath )
( cd usr/lib ; rm -rf sendmail )
( cd usr/lib ; ln -sf ../bin/smail sendmail )
( cd usr/man/preformat/cat1 ; rm -rf uupath.1.gz )
( cd usr/man/preformat/cat1 ; ln -sf pathto.1.gz uupath.1.gz )
( cd usr/man/preformat/cat8 ; rm -rf rmail.8.gz )
( cd usr/man/preformat/cat8 ; ln -sf smail.8.gz rmail.8.gz )
( cd usr/man/preformat/cat8 ; rm -rf rsmtp.8.gz )
( cd usr/man/preformat/cat8 ; ln -sf smail.8.gz rsmtp.8.gz )
( cd usr/man/preformat/cat8 ; rm -rf sendmail.8.gz )
( cd usr/man/preformat/cat8 ; ln -sf smail.8.gz sendmail.8.gz )
( cd usr/man/preformat/cat8 ; rm -rf smtpd.8.gz )
( cd usr/man/preformat/cat8 ; ln -sf smail.8.gz smtpd.8.gz )
( cd usr/man/preformat/cat8 ; rm -rf mailq.8.gz )
( cd usr/man/preformat/cat8 ; ln -sf smail.8.gz mailq.8.gz )
( cd usr/man/preformat/cat8 ; rm -rf runq.8.gz )
( cd usr/man/preformat/cat8 ; ln -sf smail.8.gz runq.8.gz )
( cd bin ; rm -rf rmail )
( cd bin ; ln -sf /usr/bin/smail rmail )
